package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsIntegrationIndustries;
import com.ruoyi.jjh.declaration.entity.dto.BmsIntegrationIndustriesAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsIntegrationIndustriesUpdateDto;
import com.ruoyi.jjh.declaration.mapper.BmsIntegrationIndustriesMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsIntegrationIndustriesService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 两业融合奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-09-04
 */
@Service
public class BmsIntegrationIndustriesServiceImpl extends ServiceImpl<BmsIntegrationIndustriesMapper,BmsIntegrationIndustries> implements IBmsIntegrationIndustriesService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    /**
     * 查询两业融合奖补
     * 
     * @param id 两业融合奖补主键
     * @return 两业融合奖补
     */
    @Override
    public BmsIntegrationIndustries selectBmsIntegrationIndustriesById(Long id) {
        return baseMapper.selectBmsIntegrationIndustriesById(id);
    }

    /**
     * 查询两业融合奖补列表
     * 
     * @param bmsIntegrationIndustries 两业融合奖补
     * @return 两业融合奖补
     */
    @Override
    public List<BmsIntegrationIndustries> selectBmsIntegrationIndustriesList(BmsIntegrationIndustries bmsIntegrationIndustries) {
        return baseMapper.selectBmsIntegrationIndustriesList(bmsIntegrationIndustries);
    }

    /**
     * 新增两业融合奖补
     * 
     * @param bmsIntegrationIndustriesAddDto 两业融合奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsIntegrationIndustries(BmsIntegrationIndustriesAddDto bmsIntegrationIndustriesAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsIntegrationIndustriesAddDto.getCreditCode()
                ,bmsIntegrationIndustriesAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsIntegrationIndustriesAddDto.getCreditCode()
                ,bmsIntegrationIndustriesAddDto.getTemplateRecordId());
        BmsIntegrationIndustries bmsIntegrationIndustries = new BmsIntegrationIndustries();
        BeanUtil.copyProperties(bmsIntegrationIndustriesAddDto,bmsIntegrationIndustries);
        bmsIntegrationIndustries.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsIntegrationIndustries);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        BeanUtil.copyProperties(bmsIntegrationIndustriesAddDto,declarationRecords);
        declarationRecords.setMatter("提交两业融合奖补申请");
        declarationRecords.setEnterpriseId(enterpriseId);
        declarationRecords.setDetailId(bmsIntegrationIndustries.getId());
        iBmsDeclarationRecordsService.save(declarationRecords);
        // 生成审核
        if (bmsIntegrationIndustriesAddDto.getStatus()==1){
            // 审批状态
            iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        }
        return num;
    }

    /**
     * 修改两业融合奖补
     * 
     * @param bmsIntegrationIndustriesUpdateDto 两业融合奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsIntegrationIndustries(BmsIntegrationIndustriesUpdateDto bmsIntegrationIndustriesUpdateDto) {
        int num = 0;
        try {
            iBmsDeclarationRecordsService.updateDeclarationRecords(bmsIntegrationIndustriesUpdateDto.getDeclarationRecordsId()
                    ,bmsIntegrationIndustriesUpdateDto.getProjectId(),bmsIntegrationIndustriesUpdateDto.getProjectName()
                    ,bmsIntegrationIndustriesUpdateDto.getStatus());

            bmsIntegrationIndustriesUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsIntegrationIndustries(bmsIntegrationIndustriesUpdateDto);
            // 申请审批
            if (bmsIntegrationIndustriesUpdateDto.getStatus()==1){
                // 审批状态
                iCommonService.insertAuditRecord(bmsIntegrationIndustriesUpdateDto.getDeclarationRecordsId(),0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        bmsIntegrationIndustriesUpdateDto.setUpdateTime(DateUtils.getNowDate());
        return num;
    }

    /**
     * 批量删除两业融合奖补
     * 
     * @param ids 需要删除的两业融合奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsIntegrationIndustriesByIds(Long[] ids) {
        return baseMapper.deleteBmsIntegrationIndustriesByIds(ids);
    }

    /**
     * 删除两业融合奖补信息
     * 
     * @param id 两业融合奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsIntegrationIndustriesById(Long id) {
        return baseMapper.deleteBmsIntegrationIndustriesById(id);
    }
}
