package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsLogisticsDevelopmentAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsLogisticsDevelopmentAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsLogisticsDevelopmentAwardUpdateDto;
import com.ruoyi.jjh.declaration.mapper.BmsLogisticsDevelopmentAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsLogisticsDevelopmentAwardService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 物流发展奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsLogisticsDevelopmentAwardServiceImpl extends ServiceImpl<BmsLogisticsDevelopmentAwardMapper,BmsLogisticsDevelopmentAward> implements IBmsLogisticsDevelopmentAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;
    /**
     * 查询物流发展奖补
     * 
     * @param id 物流发展奖补主键
     * @return 物流发展奖补
     */
    @Override
    public BmsLogisticsDevelopmentAward selectBmsLogisticsDevelopmentAwardById(Long id) {
        return baseMapper.selectBmsLogisticsDevelopmentAwardById(id);
    }

    /**
     * 查询物流发展奖补列表
     * 
     * @param bmsLogisticsDevelopmentAward 物流发展奖补
     * @return 物流发展奖补
     */
    @Override
    public List<BmsLogisticsDevelopmentAward> selectBmsLogisticsDevelopmentAwardList(BmsLogisticsDevelopmentAward bmsLogisticsDevelopmentAward) {
        return baseMapper.selectBmsLogisticsDevelopmentAwardList(bmsLogisticsDevelopmentAward);
    }

    /**
     * 新增物流发展奖补
     * 
     * @param bmsLogisticsDevelopmentAwardAddDto 物流发展奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsLogisticsDevelopmentAward(BmsLogisticsDevelopmentAwardAddDto bmsLogisticsDevelopmentAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsLogisticsDevelopmentAwardAddDto.getCreditCode()
                ,bmsLogisticsDevelopmentAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsLogisticsDevelopmentAwardAddDto.getCreditCode()
                ,bmsLogisticsDevelopmentAwardAddDto.getTemplateRecordId());
        BmsLogisticsDevelopmentAward bmsLogisticsDevelopmentAward = new BmsLogisticsDevelopmentAward();

        BeanUtil.copyProperties(bmsLogisticsDevelopmentAwardAddDto,bmsLogisticsDevelopmentAward);
        bmsLogisticsDevelopmentAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsLogisticsDevelopmentAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        BeanUtil.copyProperties(bmsLogisticsDevelopmentAwardAddDto,declarationRecords);
        declarationRecords.setMatter("提交物流发展奖补申请");
        declarationRecords.setEnterpriseId(enterpriseId);
        declarationRecords.setDetailId(bmsLogisticsDevelopmentAward.getId());
        iBmsDeclarationRecordsService.save(declarationRecords);
        // 生成审核
        if (bmsLogisticsDevelopmentAwardAddDto.getStatus()==1){
            // 审批状态
            iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        }
        return num;
    }

    /**
     * 修改物流发展奖补
     * 
     * @param bmsLogisticsDevelopmentAwardUpdateDto 物流发展奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsLogisticsDevelopmentAward(BmsLogisticsDevelopmentAwardUpdateDto bmsLogisticsDevelopmentAwardUpdateDto) {
        int num = 0;
        try {
            iBmsDeclarationRecordsService.updateDeclarationRecords(bmsLogisticsDevelopmentAwardUpdateDto.getDeclarationRecordsId()
                    ,bmsLogisticsDevelopmentAwardUpdateDto.getProjectId(),bmsLogisticsDevelopmentAwardUpdateDto.getProjectName()
                    ,bmsLogisticsDevelopmentAwardUpdateDto.getStatus());

            iBmsDeclarationRecordsService.updateProjectNameById(bmsLogisticsDevelopmentAwardUpdateDto.getId()
                    ,bmsLogisticsDevelopmentAwardUpdateDto.getProjectName(),bmsLogisticsDevelopmentAwardUpdateDto.getProjectId());
            bmsLogisticsDevelopmentAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsLogisticsDevelopmentAward(bmsLogisticsDevelopmentAwardUpdateDto);
            // 申请审批
            if (bmsLogisticsDevelopmentAwardUpdateDto.getStatus()==1){
                // 审批状态
                iCommonService.insertAuditRecord(bmsLogisticsDevelopmentAwardUpdateDto.getDeclarationRecordsId(),0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除物流发展奖补
     * 
     * @param ids 需要删除的物流发展奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsLogisticsDevelopmentAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsLogisticsDevelopmentAwardByIds(ids);
    }

    /**
     * 删除物流发展奖补信息
     * 
     * @param id 物流发展奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsLogisticsDevelopmentAwardById(Long id) {
        return baseMapper.deleteBmsLogisticsDevelopmentAwardById(id);
    }
}
