package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsManufacturingServicesAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsManufacturingServicesAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsManufacturingServicesAwardUpdateDto;
import com.ruoyi.jjh.declaration.mapper.BmsManufacturingServicesAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsManufacturingServicesAwardService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 制造服务业有效投入奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsManufacturingServicesAwardServiceImpl extends ServiceImpl<BmsManufacturingServicesAwardMapper,BmsManufacturingServicesAward> implements IBmsManufacturingServicesAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    /**
     * 查询制造服务业有效投入奖补
     * 
     * @param id 制造服务业有效投入奖补主键
     * @return 制造服务业有效投入奖补
     */
    @Override
    public BmsManufacturingServicesAward selectBmsManufacturingServicesAwardById(Long id) {
        return baseMapper.selectBmsManufacturingServicesAwardById(id);
    }

    /**
     * 查询制造服务业有效投入奖补列表
     * 
     * @param bmsManufacturingServicesAward 制造服务业有效投入奖补
     * @return 制造服务业有效投入奖补
     */
    @Override
    public List<BmsManufacturingServicesAward> selectBmsManufacturingServicesAwardList(BmsManufacturingServicesAward bmsManufacturingServicesAward) {
        return baseMapper.selectBmsManufacturingServicesAwardList(bmsManufacturingServicesAward);
    }

    /**
     * 新增制造服务业有效投入奖补
     * 
     * @param bmsManufacturingServicesAwardAddDto 制造服务业有效投入奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsManufacturingServicesAward(BmsManufacturingServicesAwardAddDto bmsManufacturingServicesAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsManufacturingServicesAwardAddDto.getCreditCode()
                ,bmsManufacturingServicesAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsManufacturingServicesAwardAddDto.getCreditCode()
                ,bmsManufacturingServicesAwardAddDto.getTemplateRecordId());
        BmsManufacturingServicesAward bmsManufacturingServicesAward = new BmsManufacturingServicesAward();
        BeanUtil.copyProperties(bmsManufacturingServicesAwardAddDto,bmsManufacturingServicesAward);
        bmsManufacturingServicesAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsManufacturingServicesAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        BeanUtil.copyProperties(bmsManufacturingServicesAwardAddDto,declarationRecords);
        declarationRecords.setMatter("提交制造服务业有效投入奖补申请");
        declarationRecords.setEnterpriseId(enterpriseId);
        declarationRecords.setDetailId(bmsManufacturingServicesAward.getId());
        iBmsDeclarationRecordsService.save(declarationRecords);
        // 生成审核
        if (bmsManufacturingServicesAwardAddDto.getStatus()==1){
            // 审批状态
            iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        }
        return num;
    }

    /**
     * 修改制造服务业有效投入奖补
     * 
     * @param bmsManufacturingServicesAwardUpdateDto 制造服务业有效投入奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsManufacturingServicesAward(BmsManufacturingServicesAwardUpdateDto bmsManufacturingServicesAwardUpdateDto) {
        int num = 0;
        try {
            iBmsDeclarationRecordsService.updateDeclarationRecords(bmsManufacturingServicesAwardUpdateDto.getDeclarationRecordsId()
                    ,bmsManufacturingServicesAwardUpdateDto.getProjectId(),bmsManufacturingServicesAwardUpdateDto.getProjectName()
                    ,bmsManufacturingServicesAwardUpdateDto.getStatus());

            bmsManufacturingServicesAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num =  baseMapper.updateBmsManufacturingServicesAward(bmsManufacturingServicesAwardUpdateDto);
            // 申请审批
            if (bmsManufacturingServicesAwardUpdateDto.getStatus()==1){
                // 审批状态
                iCommonService.insertAuditRecord(bmsManufacturingServicesAwardUpdateDto.getDeclarationRecordsId(),0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除制造服务业有效投入奖补
     * 
     * @param ids 需要删除的制造服务业有效投入奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsManufacturingServicesAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsManufacturingServicesAwardByIds(ids);
    }

    /**
     * 删除制造服务业有效投入奖补信息
     * 
     * @param id 制造服务业有效投入奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsManufacturingServicesAwardById(Long id) {
        return baseMapper.deleteBmsManufacturingServicesAwardById(id);
    }
}
