package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsPlatformConstructionAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsPlatformConstructionAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsPlatformConstructionAwardUpdateDto;
import com.ruoyi.jjh.declaration.mapper.BmsPlatformConstructionAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsPlatformConstructionAwardService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 平台建设奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
@Lazy
public class BmsPlatformConstructionAwardServiceImpl extends ServiceImpl<BmsPlatformConstructionAwardMapper,BmsPlatformConstructionAward> implements IBmsPlatformConstructionAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    /**
     * 查询平台建设奖补
     * 
     * @param id 平台建设奖补主键
     * @return 平台建设奖补
     */
    @Override
    public BmsPlatformConstructionAward selectBmsPlatformConstructionAwardById(Long id) {
        return baseMapper.selectBmsPlatformConstructionAwardById(id);
    }

    /**
     * 查询平台建设奖补列表
     * 
     * @param bmsPlatformConstructionAward 平台建设奖补
     * @return 平台建设奖补
     */
    @Override
    public List<BmsPlatformConstructionAward> selectBmsPlatformConstructionAwardList(BmsPlatformConstructionAward bmsPlatformConstructionAward) {
        return baseMapper.selectBmsPlatformConstructionAwardList(bmsPlatformConstructionAward);
    }

    /**
     * 新增平台建设奖补
     * 
     * @param bmsPlatformConstructionAwardAddDto 平台建设奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsPlatformConstructionAward(BmsPlatformConstructionAwardAddDto bmsPlatformConstructionAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsPlatformConstructionAwardAddDto.getCreditCode()
                ,bmsPlatformConstructionAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsPlatformConstructionAwardAddDto.getCreditCode()
                ,bmsPlatformConstructionAwardAddDto.getTemplateRecordId());
        BmsPlatformConstructionAward bmsPlatformConstructionAward = new BmsPlatformConstructionAward();
        BeanUtil.copyProperties(bmsPlatformConstructionAwardAddDto,bmsPlatformConstructionAward);
        bmsPlatformConstructionAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsPlatformConstructionAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        BeanUtil.copyProperties(bmsPlatformConstructionAwardAddDto,declarationRecords);
        declarationRecords.setMatter("提交平台建设奖补申请");
        declarationRecords.setEnterpriseId(enterpriseId);
        declarationRecords.setDetailId(bmsPlatformConstructionAward.getId());
        iBmsDeclarationRecordsService.save(declarationRecords);
        // 生成审核
        if (bmsPlatformConstructionAwardAddDto.getStatus()==1){
            // 审批状态
            iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        }
        return num;
    }

    /**
     * 修改平台建设奖补
     * 
     * @param bmsPlatformConstructionAwardUpdateDto 平台建设奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsPlatformConstructionAward(BmsPlatformConstructionAwardUpdateDto bmsPlatformConstructionAwardUpdateDto) {
        int num = 0;
        try {
            iBmsDeclarationRecordsService.updateDeclarationRecords(bmsPlatformConstructionAwardUpdateDto.getDeclarationRecordsId()
                    ,bmsPlatformConstructionAwardUpdateDto.getProjectId(),bmsPlatformConstructionAwardUpdateDto.getProjectName()
                    ,bmsPlatformConstructionAwardUpdateDto.getStatus());

            iBmsDeclarationRecordsService.updateProjectNameById(bmsPlatformConstructionAwardUpdateDto.getId()
                    ,bmsPlatformConstructionAwardUpdateDto.getProjectName(),bmsPlatformConstructionAwardUpdateDto.getProjectId());
            bmsPlatformConstructionAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsPlatformConstructionAward(bmsPlatformConstructionAwardUpdateDto);
            // 申请审批
            if (bmsPlatformConstructionAwardUpdateDto.getStatus()==1){
                // 审批状态
                iCommonService.insertAuditRecord(bmsPlatformConstructionAwardUpdateDto.getDeclarationRecordsId(),0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除平台建设奖补
     * 
     * @param ids 需要删除的平台建设奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsPlatformConstructionAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsPlatformConstructionAwardByIds(ids);
    }

    /**
     * 删除平台建设奖补信息
     * 
     * @param id 平台建设奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsPlatformConstructionAwardById(Long id) {
        return baseMapper.deleteBmsPlatformConstructionAwardById(id);
    }
}
